==> com.github.weisj.jsvg.source_1.7.2.jar: com/github/weisj/jsvg/geometry/FillRuleAwareAWTSVGShape.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021-2024 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.geometry;

import java.awt.geom.Path2D;

import org.jetbrains.annotations.NotNull;

import com.github.weisj.jsvg.attributes.value.Value;
import com.github.weisj.jsvg.renderer.RenderContext;

public final class FillRuleAwareAWTSVGShape extends AWTSVGShape<Path2D> {

    public FillRuleAwareAWTSVGShape(@NotNull Value<Path2D> shape) {
        super(shape);
    }

    @Override
    public @NotNull Path2D shape(@NotNull RenderContext context, boolean validate) {
        Path2D shape = super.shape(context, validate);
        shape.setWindingRule(context.fillRule().awtWindingRule);
        return shape;
    }
}

==> com.github.weisj.jsvg.source_2.0.0.jar: com/github/weisj/jsvg/geometry/FillRuleAwareAWTSVGShape.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021-2025 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.geometry;

import java.awt.geom.Path2D;

import org.jetbrains.annotations.NotNull;

import com.github.weisj.jsvg.attributes.value.Value;
import com.github.weisj.jsvg.renderer.RenderContext;
import com.github.weisj.jsvg.renderer.impl.context.RenderContextAccessor;

public final class FillRuleAwareAWTSVGShape extends AWTSVGShape<Path2D> {

    public FillRuleAwareAWTSVGShape(@NotNull Value<Path2D> shape) {
        super(shape);
    }

    @Override
    public @NotNull Path2D shape(@NotNull RenderContext context, boolean validate) {
        Path2D shape = super.shape(context, validate);
        shape.setWindingRule(RenderContextAccessor.instance().fillRule(context).awtWindingRule);
        return shape;
    }
}
